@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -22,7 +22,7 @@ void GroupManagementWidgetTest::shouldHaveDefaultValues()
     GroupManagementWidget w;
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), {});
+    QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
     auto mListWidget = w.findChild<QListWidget *>(QStringLiteral("mListWidget"));
     QVERIFY(mListWidget);
